BaseController

Struct BaseController 

pub struct BaseController<Body>
where Body: Debug + 'static,
{ /* private fields */ }
A Singleton Controller implementation.

In PureMVC, the Controller class follows the ‘Command and Controller’ strategy, and assumes these responsibilities:

Your application must register Command’s with the Controller. The simplest way is to subclass Facade, and use its register_command method to add your registrations.

Implementations

Source

impl<Body> BaseController<Body>
where Body: Debug + 'static,

pub fn new() -> Self

Create instance of BaseController.

Actually, you have to reimplement the Controller for your purposes with Singleton pattern.

This View implementation is keept here in educational purposes only.

pub fn as_context(&self) -> Rc<dyn NotifyContext>

Reprecent controller as NotifyContext