RepositoryProvider

Enum RepositoryProvider 

pub enum RepositoryProvider {
    GitHub(Url),
    GitLab(Url),
}
Describes supported repository providers.

Variants



GitHub(Url)

Github provider



GitLab(Url)

Gitlab provider

Implementations

Source

impl RepositoryProvider

pub fn build_issue_url( &self, info: &PanicInfo<'_>, metadata: &PackageMetadata<'_>, ) -> Url

Returns the full URL required to file an issue in the repository of the client crate.

Most Git providers allow issue creation through query params