pub enum RepositoryProvider {
GitHub(Url),
GitLab(Url),
}Expand description
Describes supported repository providers.
Variants
Implementations
Sourceimpl RepositoryProvider
impl RepositoryProvider
Sourcepub fn build_issue_url(
&self,
info: &PanicInfo<'_>,
metadata: &PackageMetadata<'_>,
) -> Url
pub fn build_issue_url( &self, info: &PanicInfo<'_>, metadata: &PackageMetadata<'_>, ) -> Url
Returns the full URL required to file an issue in the repository of the client crate.
Most Git providers allow issue creation through query params